@@ -24,7 +24,7 @@ use vars qw($VERSION);
 use Image::ExifTool qw(:DataAccess :Utils);
 use Image::ExifTool::Exif;
 
-$VERSION = '1.41';
+$VERSION = '1.42';
 
 sub ProcessKodakIFD($$$);
 sub ProcessKodakText($$$);
@@ -189,6 +189,7 @@ sub WriteKodakIFD($$$);
             1 => 'Flash?',
             2 => 'Tungsten',
             3 => 'Daylight',
+            # 5 - seen this for "Auto" with a ProBack 645M
         },
     },
     0x5c => {
@@ -1527,12 +1528,14 @@ my %sceneModeUsed = (
     'Exposure Mode' => {
         Name => 'ExposureMode',
         PrintConv => {
+            OTHER => sub { shift }, # pass other values straight through
             'M' => 'Manual',
             'A' => 'Aperture Priority', #(NC -- I suppose this could be "Auto" too)
             'S' => 'Shutter Priority', #(NC)
             'P' => 'Program', #(NC)
             'B' => 'Bulb', #(NC)
             # have seen "Manual (M)" written by DCS760C - PH
+            # and "Aperture priority AE (Av)" written by a ProBack 645M
         },
     },
     'Firmware Version' => 'FirmwareVersion',
@@ -2069,7 +2072,7 @@ interpret Kodak maker notes EXIF meta information.
 
 =head1 AUTHOR
 
-Copyright 2003-2016, Phil Harvey (phil at owl.phy.queensu.ca)
+Copyright 2003-2018, Phil Harvey (phil at owl.phy.queensu.ca)
 
 This library is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
